/*******************************************************************************
 * Licensed Materials - Property of IBM
 * Copyright IBM Corp. 2009, 2010.  All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 *******************************************************************************/
(function() {
dojo.provide("deploy.rmps.properties.CapabilitiesSection");

dojo.require("dijit._Widget");
dojo.require("dojo.i18n");

dojo.require("rmps.app.core.util");

dojo.require("jazz.ui.StyledTable");
dojo.require("jazz.ui.ResourceLink");

dojo.requireLocalization("deploy.rmps.properties", "CapabilitiesSectionMessages");
	
var messages = dojo.i18n.getLocalization("deploy.rmps.properties", "CapabilitiesSectionMessages");

dojo.declare("deploy.rmps.properties.CapabilitiesSection", dijit._Widget, {
	
	"class": "deploy-rmps-properties-capabilitiesSection",
	
	// mixin properties
	/*
	 * capabilities: [
	 *                {
	 *                    category: "",
	 *                    value: { // or array
	 *                               label: "",
	 *                               uri: "" || null
	 *                           }
	 *                }
	 *            ]
	 */
	
	postCreate: function() {
		this.containerNode = this.domNode;
		
		var columns = [
			{
				label: messages.column_property,
			},
			{
				label: messages.column_value,
			}
		];
		
		var table = new jazz.ui.StyledTable({
			columns: columns	
		});
		
		if (this.tableData) {
			
			var lastCategory = null;
			
			for (var i = 0, data; data = this.tableData[i]; ++i) {
				// assume data is ordered by category from the server
				if (data.category !== lastCategory) {
					// add category
					table.tbody.appendChild(this._createCategoryRow(data.category));
					lastCategory = data.category;
				}
				table.tbody.appendChild(this._createLinkRow(data));
			}
		}
		
		if (this._hasEmpty) {
			this._addHideEmptyCheckbox();
		}
		
		this.domNode.appendChild(table.domNode);
	},
	
	_isHideEmpty: function() {
		var value = dojo.cookie(this.sectionId);
		if (value) {
			return dojo.fromJson(value).hideEmpty || false;
		}
		return false;
	},
	
	_saveHideEmpty: function(hideEmpty) {
		var value = dojo.cookie(this.sectionId);
		if (value) {
			var cookie = dojo.fromJson(value);
		} else {
			cookie = {};
		}
		cookie.hideEmpty = hideEmpty;
		dojo.cookie(this.sectionId, dojo.toJson(cookie), {expires: 90});
	},
	
	_addHideEmptyCheckbox: function() {
		var container = dojo.create("div", {className: "header"}, this.domNode);
		
		var hideEmpty = this._isHideEmpty();
		
		var cb = new dijit.form.CheckBox({
				checked: hideEmpty,
				onChange: dojo.hitch(this, function(checked) {
					this._saveHideEmpty(checked);
					dojo[checked ? "addClass" : "removeClass"](this.domNode, "hideEmpty");
				})
		});
		container.appendChild(cb.domNode);
		
		dojo.create("label", {"for": cb.id}, container).appendChild(dojo.doc.createTextNode(messages.hideEmpty));
		
		// reset cookie expiration
		this._saveHideEmpty(hideEmpty);
		dojo[hideEmpty ? "addClass" : "removeClass"](this.domNode, "hideEmpty");
		
		container = hideEmpty = cb = null;
	},
	
	_createCategoryRow: function(category) {
		var tr = dojo.create("tr");
		var categoryCell = dojo.create("td", {"class": "category"}, tr);
		categoryCell.appendChild(dojo.doc.createTextNode(category));
		
		var emptyCell = dojo.create("td", null, tr);
		emptyCell.innerHTML = "&nbsp;";
		
		return tr;
	},
	
	_createLinkRow: function(rowData) {
		var tr = dojo.create("tr");
		var nameCell = dojo.create("td", {"class": "label"}, tr);
		var valueCell = dojo.create("td", {"class": "value"}, tr);
		
		nameCell.appendChild(dojo.doc.createTextNode(rowData.label || ""));

		var isEmpty = false;
		var value = rowData.value;
		if (value) {
			if (dojo.isArray(value)) {
				if (value.length > 0) {
					for (var i = 0; i < value.length; ++i) {
						if (i != 0) {
							valueCell.appendChild(dojo.create("br"));
						}
						this._populateValueCell(valueCell, value[i]);
					}
				} else {
					valueCell.innerHTML = "&nbsp;";
					isEmpty = true;
				}
			} else {
				isEmpty = !this._populateValueCell(valueCell, value);
			}
		} else {
			valueCell.innerHTML = "&nbsp;";
			isEmpty = true;
		}
		
		if (isEmpty) {
			dojo.addClass(tr, "empty");
			this._hasEmpty = true;
		}
		
		return tr;
	},
	
	_populateValueCell: function(valueCell, value) {
		if (value.uri) {
			var presentationUri = rmps.app.core.util.getViewResourceUri(value.uri);
			var linkNode = dojo.create("a", {href: presentationUri}, valueCell);
			linkNode.appendChild(dojo.doc.createTextNode(value.label));
			
			new jazz.ui.ResourceLink({
						retainLinkText: true, 
						lazyFetch: true, 
						uri: net.jazz.ajax._contextRoot + "/rendering?resourceUri=" +  encodeURIComponent(value.uri), 
						presentationUri: presentationUri
					}, linkNode);
			
		} else if (value.label != null && value.label.length > 0) {
			valueCell.appendChild(dojo.doc.createTextNode(value.label));
			
		} else {
			valueCell.innerHTML += "&nbsp;";
			return false;
		}
		return true;
	}
});

})();