/*******************************************************************************
 * Licensed Materials - Property of IBM
 * Copyright IBM Corp. 2009, 2010.  All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 *******************************************************************************/
(function() {
dojo.provide("deploy.rmps.properties.LinksSection");

dojo.require("dijit._Widget");
dojo.require("dojo.i18n");

dojo.require("rmps.app.core.util");

dojo.require("jazz.ui.StyledTable");
dojo.require("jazz.ui.ResourceLink");

dojo.requireLocalization("deploy.rmps.properties", "LinksSectionMessages");
	
var messages = dojo.i18n.getLocalization("deploy.rmps.properties", "LinksSectionMessages");

dojo.declare("deploy.rmps.properties.LinksSection", dijit._Widget, {
	
	"class": "deploy-rmps-properties-linksSection",
	
	// mixin properties
	/*
	 * links: [
	 *                {
	 *                    category: "",
	 *                    value: { // or array
	 *                               label: "",
	 *                               uri: "" || null
	 *                           }
	 *                }
	 *            ]
	 */
	
	postCreate: function() {
		this.containerNode = this.domNode;
		
		var columns = [
			{
				label: messages.column_name,
				width: "34%"
			},
			{
				label: messages.column_source,
				width: "33%"
			},
			{
				label: messages.column_target,
				width: "33%"
			}
		];
		
		var table = new jazz.ui.StyledTable({
			columns: columns	
		});
		
		if (this.links) {
			
			var lastCategory = null;
			
			for (var i = 0, link; link = this.links[i]; ++i) {
				// assume data is ordered by category from the server
				if (link.category !== lastCategory) {
					// add category
					table.tbody.appendChild(this._createCategoryRow(link.category));
					lastCategory = link.category;
				}
				table.tbody.appendChild(this._createLinkRow(link));
			}
		}
		
		this.domNode.appendChild(table.domNode);
	},
	
	_createCategoryRow: function(category) {
		var tr = dojo.create("tr");
		var categoryCell = dojo.create("td", {"class": "category"}, tr);
		categoryCell.appendChild(dojo.doc.createTextNode(category));
		
		var emptyCell = dojo.create("td", null, tr);
		emptyCell.innerHTML = "&nbsp;";
		
		return tr;
	},
	
	_createLinkRow: function(rowData) {
		var tr = dojo.create("tr");
		var nameCell = dojo.create("td", {"class": "name"}, tr);
		var sourceCell = dojo.create("td", {"class": "source"}, tr);
		var targetCell = dojo.create("td", {"class": "target"}, tr);
		
		nameCell.appendChild(dojo.doc.createTextNode(rowData.name || ""));

		var value = rowData.source;
		if (value) {
			!this._populateValueCell(sourceCell, value);
		} else {
			sourceCell.innerHTML = "&nbsp;";
		}
		
		var value = rowData.target;
		if (value) {
			isEmpty = !this._populateValueCell(targetCell, value);
		} else {
			targetCell.innerHTML = "&nbsp;";
		}
		return tr;
	},
	
	_populateValueCell: function(valueCell, value) {
		if (value.uri) {
			var presentationUri = rmps.app.core.util.getViewResourceUri(value.uri);
			var linkNode = dojo.create("a", {href: presentationUri}, valueCell);
			linkNode.appendChild(dojo.doc.createTextNode(value.label));
			
			new jazz.ui.ResourceLink({
						retainLinkText: true, 
						lazyFetch: true, 
						uri: net.jazz.ajax._contextRoot + "/rendering?resourceUri=" +  encodeURIComponent(value.uri), 
						presentationUri: presentationUri
					}, linkNode);
			
		} else if (value.label != null && value.label.length > 0) {
			valueCell.appendChild(dojo.doc.createTextNode(value.label));
			
		} else {
			valueCell.innerHTML += "&nbsp;";
			return false;
		}
		return true;
	}
});

})();